@@ -459,7 +459,7 @@ resizer.onResize = function ()
 			//Do nothing
 		}
 		
-		Arnolfini.resizeImg("#FrontPageManagerRight .portletWrapper .portletCollection", "mini");
+		Arnolfini.resizeImg("#FrontPageManagerRight .portletWrapper .portletCollection", "portlet");
 		
 		$("#FrontPageManagerRight").after($("#FrontPageManagerLeft"))
 	}
